Module detection
arrow_
graph
0.6.2
Module detection
Module Items
Structs
Enums
In arrow_
graph::
streaming
arrow_graph
::
streaming
Module
detection
Structs

Anomaly
Event
Detected anomaly event
Anomaly
Thresholds
Thresholds for detecting anomalous changes
Graph
Change
Detected significant graph change
Graph
Change
Detector
Graph change detection algorithms for anomaly detection and community drift These algorithms monitor graph evolution and detect significant structural changes
Graph
Metrics
Key graph metrics for anomaly detection
Enums

Anomaly
Type
Types of anomalies that can be detected
Change
Type
Types of significant structural changes